@@ -1,4 +1,9 @@
 #!/usr/bin/env python
+def change_name(name):
+    prompt = main()
+    return prompt.replace("🍊小橙", name)
+
+
 def main():
     prompt = '''
 ### 問候
